#
# -*- coding: utf-8 -*-
# (C) Copyright: Profound Networks, LLC 2019
#
"""Top-level package for gzipi."""

from .lib import index_csv_file, index_json_file, retrieve, search
from .lib import repack_json_file, repack_csv_file

__version__ = '0.1.0'
